@@ -12,7 +12,7 @@ use warnings;
 # It is provided simply to keep CPAN happy:
 #   cpan -i IO::Async
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 =head1 NAME
 
@@ -23,14 +23,12 @@ C<IO::Async> - perform asynchronous filehandle IO and other operations
  use IO::Async::Stream;
  use IO::Async::Loop;
 
- use Socket qw( SOCK_STREAM );
-
  my $loop = IO::Async::Loop->new();
 
  $loop->connect(
     host     => "some.other.host",
     service  => 12345,
-    socktype => SOCK_STREAM,
+    socktype => 'stream',
 
     on_connected => sub {
        my ( $socket ) = @_;
